# <img src='./logo.svg' card_color="#FF8600" width="50" style="vertical-align:bottom" style="vertical-align:bottom">Ready

## Summary

Skill to speak a notification when Neon is ready.

## Description

When Neon is started or restarted, this skill will speak a notification to the
user. This speech can be enabled/disabled by intent.

## Examples

- "Enable ready notifications."
- "Disable load speech."

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[NeonGeckoCom](https://github.com/NeonGeckoCom)

## Category
**Daily**

## Tags
#NeonGecko Original
#NeonAI
